@@ -15,11 +15,11 @@ App::Prove - Implements the C<prove> command.
 
 =head1 VERSION
 
-Version 3.04
+Version 3.05
 
 =cut
 
-$VERSION = '3.04';
+$VERSION = '3.05';
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,10 @@ wrapper around an instance of this module.
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
 use constant IS_VMS => $^O eq 'VMS';
-use constant STATE_FILE => ( IS_WIN32 || IS_VMS ) ? '_prove' : '.prove';
+use constant IS_UNIXY => !( IS_VMS || IS_WIN32 );
+
+use constant STATE_FILE => IS_UNIXY ? '.prove'   : '_prove';
+use constant RC_FILE    => IS_UNIXY ? '.proverc' : '_proverc';
 
 use constant PLUGINS => 'App::Prove::Plugin';
 
@@ -80,6 +83,7 @@ sub new {
 
     my $self = bless {
         argv          => [],
+        rc_opts       => [],
         includes      => [],
         modules       => [],
         state         => [],
@@ -98,9 +102,30 @@ sub new {
     return $self;
 }
 
+=head3 C<add_rc_file>
+
+    $prove->add_rc_file('myproj/.proverc');
+
+Called before C<process_args> to prepend the contents of an rc file to
+the options.
+
+=cut
+
+sub add_rc_file {
+    my ( $self, $rc_file ) = @_;
+
+    local *RC;
+    open RC, "<$rc_file" or croak "Can't read $rc_file ($!)";
+    while ( defined( my $line = <RC> ) ) {
+        push @{ $self->{rc_opts} }, grep $_ && $_ !~ /^#/,
+          $line =~ m{ ' ([^']*) ' | " ([^"]*) " | (\#.*) | (\S*) }xg;
+    }
+    close RC;
+}
+
 =head3 C<process_args>
 
-  $prove->process_args(@args);
+    $prove->process_args(@args);
 
 Processes the command-line arguments. Attributes will be set
 appropriately. Any filenames may be found in the C<argv> attribute.
@@ -110,21 +135,48 @@ Dies on invalid arguments.
 =cut
 
 sub process_args {
-    my ( $self, @args ) = @_;
+    my $self = shift;
 
+    my @rc = RC_FILE;
+    unshift @rc, glob '~/' . RC_FILE if IS_UNIXY;
+
+    # Preprocess meta-args.
+    my @args;
+    while ( defined( my $arg = shift ) ) {
+        if ( $arg eq '--norc' ) {
+            @rc = ();
+        }
+        elsif ( $arg eq '--rc' ) {
+            defined( my $rc = shift )
+              or croak "Missing argument to --rc";
+            push @rc, $rc;
+        }
+        elsif ( $arg =~ m{^--rc=(.+)$} ) {
+            push @rc, $1;
+        }
+        else {
+            push @args, $arg;
+        }
+    }
+
+    # Everything after the arisdottle '::' gets passed as args to
+    # test programs.
     if ( defined( my $stop_at = _first_pos( '::', @args ) ) ) {
         my @test_args = splice @args, $stop_at;
         shift @test_args;
         $self->{test_args} = \@test_args;
     }
 
+    # Grab options from RC files
+    $self->add_rc_file($_) for grep -f, @rc;
+    unshift @args, @{ $self->{rc_opts} };
+
     if ( my @bad = map {"-$_"} grep {/^-(man|help)$/} @args ) {
         die "Long options should be written with two dashes: ",
           join( ', ', @bad ), "\n";
     }
 
-    # Allow cuddling the paths with the -I
-    @args = map { /^(-I)(.+)/ ? ( $1, $2 ) : $_ } @args;
+    # And finally...
 
     {
         local @ARGV = @args;
